==> jasperreports_3.7.0+dfsg.orig.tar.gz: jasperreports-3.7.0.orig/src/net/sf/jasperreports/charts/xml/JRBubblePlotFactory.java <==
/*
 * JasperReports - Free Java Reporting Library.
 * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
 * http://www.jaspersoft.com
 *
 * Unless you have purchased a commercial license agreement from Jaspersoft,
 * the following license terms apply:
 *
 * This program is part of JasperReports.
 *
 * JasperReports is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * JasperReports is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
 */
package net.sf.jasperreports.charts.xml;

import net.sf.jasperreports.charts.design.JRDesignBubblePlot;
import net.sf.jasperreports.engine.JRChart;
import net.sf.jasperreports.engine.xml.JRBaseFactory;
import net.sf.jasperreports.engine.xml.JRXmlConstants;

import org.xml.sax.Attributes;

/**
 * @author Flavius Sana (flavius_sana@users.sourceforge.net)
 * @version $Id: JRBubblePlotFactory.java 3032 2009-08-27 11:32:28Z teodord $
 */
public class JRBubblePlotFactory extends JRBaseFactory {
	
	private static final String ATTRIBUTE_scaleType = "scaleType";
	
	public Object createObject( Attributes attributes ){
		JRChart chart = (JRChart)digester.peek();
		JRDesignBubblePlot plot = (JRDesignBubblePlot)chart.getPlot();
		
		
		String scaleType = attributes.getValue( ATTRIBUTE_scaleType );
		Integer intScaleType = (Integer)JRXmlConstants.getScaleTypeMap().get( scaleType );
		if( intScaleType != null ){
			plot.setScaleType( intScaleType  );
		}

		return plot;
	}

}

==> jasperreports3.7_3.7.6+dfsg.orig.tar.gz: jasperreports3.7-3.7.6.orig/src/net/sf/jasperreports/charts/xml/JRBubblePlotFactory.java <==
/*
 * JasperReports - Free Java Reporting Library.
 * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
 * http://www.jaspersoft.com
 *
 * Unless you have purchased a commercial license agreement from Jaspersoft,
 * the following license terms apply:
 *
 * This program is part of JasperReports.
 *
 * JasperReports is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * JasperReports is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
 */
package net.sf.jasperreports.charts.xml;

import net.sf.jasperreports.charts.design.JRDesignBubblePlot;
import net.sf.jasperreports.charts.type.ScaleTypeEnum;
import net.sf.jasperreports.engine.JRChart;
import net.sf.jasperreports.engine.xml.JRBaseFactory;

import org.xml.sax.Attributes;

/**
 * @author Flavius Sana (flavius_sana@users.sourceforge.net)
 * @version $Id: JRBubblePlotFactory.java 3559 2010-03-10 10:31:16Z shertage $
 */
public class JRBubblePlotFactory extends JRBaseFactory {
	
	private static final String ATTRIBUTE_scaleType = "scaleType";
	
	public Object createObject( Attributes attributes ){
		JRChart chart = (JRChart)digester.peek();
		JRDesignBubblePlot plot = (JRDesignBubblePlot)chart.getPlot();
		
		
		ScaleTypeEnum scaleType = ScaleTypeEnum.getByName(attributes.getValue(ATTRIBUTE_scaleType));
		if( scaleType != null ){
			plot.setScaleType( scaleType  );
		}

		return plot;
	}

}
